@@ -51,7 +51,7 @@ def mask_data(data, mask_prob, one_in_middle=False):
     return data, bool_mask
 
 
-def vect_batch(batch, mask_prob, one_in_middle, to_one_hot=True):
+def vect_batch(batch, mask_prob, one_in_middle=False, to_one_hot=True):
     x = np.concatenate(batch, axis=0)
     y = x.copy()
 
@@ -64,43 +64,33 @@ def vect_batch(batch, mask_prob, one_in_middle, to_one_hot=True):
     return x, y, mask
 
 
-def random_iter(seq_len, masked_size, batch_size, overfit_batch=False):
-    while True:
-        seq_in_ = np.random.choice(len(AA_DISTRIBUTION), batch_size * seq_len, p=AA_DISTRIBUTION)
+def line_to_seqtok(line, seq_len, random=''):
+    _, _, seq = line[:-1].split('\t')
+    prot_len = len(seq[:-1])
+    if prot_len <= seq_len:
+        return None
 
-        seq_in = np.zeros((batch_size * seq_len, len(AA_DISTRIBUTION)))
-        arang = np.arange(0, seq_in.shape[0])
+    offset = np.random.randint(0, prot_len - seq_len + 1)
+    seq = seq[offset:offset + seq_len]
 
-        seq_in[arang, seq_in_] = 1.0
-        seq_in = seq_in.reshape((batch_size, seq_len, len(AA_DISTRIBUTION)))
+    if random == 'full':
+        seq = ''.join(list(map(lambda x: AA_DICT_REV[x], np.random.randint(3, 23, seq_len))))
 
-        m_offset = np.random.randint(0, seq_len - masked_size + 1)
-        seq_out = seq_in[:, m_offset:m_offset + masked_size, :].copy()
-        seq_in[:, m_offset:m_offset + masked_size, :] = 0.0
+    seq_in = tokenize(seq)
 
-        if overfit_batch:
-            while True:
-                yield seq_in, seq_out
+    if seq_in is None:
+        return None
 
-        yield seq_in, seq_out
+    return seq_in
 
 
-def ds_iter(src_file, seq_len, mask_prob, batch_size, one_in_middle=False, to_one_hot=True):
+def ds_iter(src_file, seq_len, mask_prob, batch_size, one_in_middle=False, to_one_hot=True, random=''):
     batch = []
     while True:
         with open(src_file, "r", encoding="utf-8") as fr:
             fr.readline()
             for line in fr:
-                _, _, seq = line[:-1].split('\t')
-                prot_len = len(seq[:-1])
-                if prot_len <= seq_len:
-                    continue
-
-                offset = np.random.randint(0, prot_len - seq_len + 1)
-                seq = seq[offset:offset + seq_len]
-
-                seq_in = tokenize(seq)
-
+                seq_in = line_to_seqtok(line, seq_len, random)
                 if seq_in is None:
                     continue
 
@@ -112,8 +102,8 @@ def ds_iter(src_file, seq_len, mask_prob, batch_size, one_in_middle=False, to_on
                     del batch[:]
 
 
-def double_mask(src_file, seq_len, mask_prob_1, mask_prob_2, batch_size, use_mask):
-    wrapped_iter = ds_iter(src_file, seq_len, mask_prob_1, batch_size, to_one_hot=False)
+def double_mask(src_file, seq_len, mask_prob_1, mask_prob_2, batch_size, use_mask, random=''):
+    wrapped_iter = ds_iter(src_file, seq_len, mask_prob_1, batch_size, to_one_hot=False, random=random)
 
     while True:
         x, y, mask = next(wrapped_iter)
@@ -137,7 +127,7 @@ if __name__ == '__main__':
     ROOT = Path(r'C:\DATA\ML-Data\BioML\datasets\UniRef90')
 
     # ds_it = ds_iter(ROOT / 'refprot_random_taxfree.tsv', 64, 0.15, 1024, True)
-    ds_it = double_mask(ROOT / 'refprot_random_taxfree.tsv', 24, 0.15, 0.35, 32, False)
+    ds_it = double_mask(ROOT / 'refprot_random_taxfree.tsv', 24, 0.15, 0.35, 32, False, 'full')
 
     for i in range(1000):
         a = next(ds_it)
